@@ -23,6 +23,7 @@ def run(
     env: dict = {},
     ports: dict = {},
     routes: dict = {},
+    volumes: dict = {},
     build: bool = False,
     upstream: str = None,
     detach: bool = False,
@@ -49,13 +50,12 @@ def run(
             image = context.image
             remote_image = False
 
-        volumes = context.get('volumes', {})
         if not isinstance(volumes, dict):
             raise TaskCreationError('Invalid volume configuration')
 
         # if we are using the image of the current context, automatically mount the working directory
         # todo: add an option to disable this
-        if not remote_image:
+        if not remote_image or image == 'cowait/notebook':
             volumes['/var/task'] = {
                 'bind': {
                     'src': context.root_path,
@@ -72,16 +72,13 @@ def run(
             name=task,
             image=image,
             inputs=inputs,
-            env={
-                **context.environment,
-                **env,
-            },
+            env=context.extend('environment', env),
             ports=ports,
             routes=routes,
             parent=None,  # root task
             upstream=context.coalesce('upstream', upstream, agent),
             owner=getpass.getuser(),
-            volumes=volumes,
+            volumes=context.extend('volumes', volumes),
             cpu=context.override('cpu', cpu),
             cpu_limit=context.override('cpu_limit', cpu_limit),
             memory=context.override('memory', memory),
