@@ -1,10 +1,11 @@
 from __future__ import annotations
-import json
 from abc import abstractmethod
 from typing import Iterable
 from cowait.tasks import TaskDefinition, RemoteTask
 from cowait.utils import EventEmitter
-from .const import ENV_TASK_CLUSTER, ENV_TASK_DEFINITION
+from .const import ENV_TASK_CLUSTER, ENV_TASK_DEFINITION, ENV_GZIP_ENABLED, MAX_ENV_LENGTH
+from .errors import ProviderError
+from .utils import env_pack
 
 
 class ClusterProvider(EventEmitter):
@@ -62,11 +63,23 @@ class ClusterProvider(EventEmitter):
         Returns:
             env (dict): Environment variable dict
         """
-        return {
+
+        env = {
             **taskdef.env,
-            ENV_TASK_CLUSTER:    json.dumps(self.serialize()),
-            ENV_TASK_DEFINITION: json.dumps(taskdef.serialize()),
+            ENV_GZIP_ENABLED:    '1',
+            ENV_TASK_CLUSTER:    env_pack(self.serialize()),
+            ENV_TASK_DEFINITION: env_pack(taskdef.serialize()),
         }
 
+        # check total length of environment data
+        length = 0
+        for key, value in env.items():
+            length += len(str(key)) + len(str(value))
+
+        if length > MAX_ENV_LENGTH:
+            raise ProviderError(f'Task environment too long. Was {length}, max: {MAX_ENV_LENGTH}')
+
+        return env
+
     def find_agent(self):
         return None
