@@ -4,13 +4,13 @@ from asyncio import sleep
 
 from .status import WORK, WAIT, DONE, STOP, FAIL
 from .messages import TASK_INIT, TASK_STATUS, TASK_LOG, TASK_FAIL, TASK_RETURN
-from .errors import TaskError, TaskNotFoundError
+from .errors import TaskError, TaskNotFoundError, StoppedError
 
 from .task import Task
 from .remote_task import RemoteTask
 from .definition import TaskDefinition
 from .instance import TaskInstance
-from .decorator import task, spawn
+from .decorator import task, spawn, input, exit
 from .ops import join, wait
 
 from .components.rpc import rpc
