@@ -2,7 +2,7 @@ from cowait.tasks.shell import ShellTask
 
 
 class SparkWorker(ShellTask):
-    async def run(self, master: str, cores: int = 2) -> dict:
+    async def run(self, master: str, cores: int = 2, memory = '4G') -> dict:
         return await super().run(
             command=' '.join([
                 'spark-class',
@@ -11,5 +11,6 @@ class SparkWorker(ShellTask):
             ]),
             env={
                 'SPARK_WORKER_CORES': str(cores),
+                'SPARK_WORKER_MEMORY': memory,
             },
         )
