@@ -1,3 +1,4 @@
+import time
 import asyncio
 from threading import Thread
 
@@ -6,25 +7,19 @@ class IOThread(Thread):
     def __init__(self):
         super().__init__()
         self.loop = None
-        self._queue = []
 
     def run(self):
+        # create a new event loop and set it as default loop for this thread
         self.loop = asyncio.new_event_loop()
         asyncio.set_event_loop(self.loop)
-
-        # schedule any queued tasks
-        for coro in self._queue:
-            self.create_task(coro)
-        self._queue = []
-
-        # run event loop
         self.loop.run_forever()
 
-    def create_task(self, coro):
-        # if the loop is not ready yet, queue it
-        if self.loop is None:
-            self._queue.append(coro)
-            return
+    def start(self):
+        # start thread and block until the event loop is ready
+        super().start()
+        while self.loop is None:
+            time.sleep(0.01)
 
+    def create_task(self, coro):
         future = asyncio.run_coroutine_threadsafe(coro, loop=self.loop)
         return asyncio.wrap_future(future)
