@@ -1,9 +1,10 @@
-
+import asyncio
 from typing import Any
 from cowait.network import Client
 from cowait.tasks import TaskDefinition, WORK, DONE, STOP, FAIL
-from cowait.tasks.messages import \
-    TASK_INIT, TASK_LOG, TASK_STATUS, TASK_RETURN, TASK_FAIL
+from cowait.tasks.messages import TASK_INIT, TASK_LOG, TASK_STATUS, TASK_RETURN, TASK_FAIL, TASK_STATS
+from cowait.version import version
+from .logger import Logger, JSONLogger
 
 
 class ParentClient(Client):
@@ -11,14 +12,26 @@ class ParentClient(Client):
     Upstream API client.
     """
 
-    def __init__(self, id: str):
+    def __init__(self, id, io_loop, logger: Logger = None):
         super().__init__()
         self.id = id
+        self.io = io_loop
+        self.logger = logger or JSONLogger()
 
     async def connect(self, url: str, token: str = None) -> None:
+        if url is None:
+            return
+
         if token is None:
             token = self.id
-        return await super().connect(url, token)
+
+        # super.connect() blocks for the duration of the connection
+        # run it on the I/O loop
+        self.io.create_task(super().connect(url, token))
+
+        # block caller until connected
+        while not self.connected:
+            await asyncio.sleep(0.1)
 
     async def msg(self, type: str, **msg) -> None:
         """
@@ -34,6 +47,12 @@ class ParentClient(Client):
             **msg,
         })
 
+    async def send(self, msg: dict):
+        # send messages on the I/O loop
+        self.io.create_task(self.logger.handle(msg))
+        if self.connected:
+            await self.io.create_task(super().send(msg))
+
     async def send_init(self, taskdef: TaskDefinition) -> None:
         """
         Send a task initialization message.
@@ -41,7 +60,11 @@ class ParentClient(Client):
         Arguments:
             taskdef (TaskDefinition): New task definition
         """
-        await self.msg(TASK_INIT, task=taskdef.serialize())
+        await self.msg(
+            TASK_INIT,
+            task=taskdef.serialize(),
+            version=version,
+        )
 
     async def send_run(self) -> None:
         """ Send status update: Running """
@@ -51,7 +74,6 @@ class ParentClient(Client):
         """ Send status update: Stopped """
         id = self.id if id is None else id
         await self.msg(TASK_STATUS, status=STOP, id=id)
-        await self.msg(TASK_RETURN, result={}, id=id)
 
     async def send_done(self, result: Any, result_type: str = 'any') -> None:
         """
@@ -61,8 +83,8 @@ class ParentClient(Client):
             result (any): Any serializable data to return to the upstream task.
             result_type (str): Result type description
         """
-        await self.msg(TASK_STATUS, status=DONE)
         await self.msg(TASK_RETURN, result=result, result_type=result_type)
+        await self.msg(TASK_STATUS, status=DONE)
 
     async def send_fail(self, error: str) -> None:
         """
@@ -71,8 +93,8 @@ class ParentClient(Client):
         Arguments:
             error (str): Error message
         """
-        await self.msg(TASK_STATUS, status=FAIL)
         await self.msg(TASK_FAIL,   error=error)
+        await self.msg(TASK_STATUS, status=FAIL)
 
     async def send_log(self, file: str, data: str) -> None:
         """
@@ -83,3 +105,6 @@ class ParentClient(Client):
             data (str): Captured output data
         """
         await self.msg(TASK_LOG, file=file, data=data)
+
+    async def send_stats(self, stats: dict) -> None:
+        await self.msg(TASK_STATS, **stats)
